Properties Methods Events Config Options Direct Link

# Class Ext.tree.ColumnResizer

Package: | Ext.tree
Defined In: | TreeGridColumnResizer.js
Class: | ColumnResizer
Extends: | Object

## Config Options

Config Options | Defined By
--- | ---
| minWidth : Number The minimum width the column can be dragged to. Defaults to `14`. | ColumnResizer
| minWidth : Number The minimum width the column can be dragged to. Defaults to `14`. | ColumnResizer

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.